# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ItemSearchInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'asset': 'str',
        'filters': 'list[str]',
        'include_properties': 'list[str]',
        'limit': 'int',
        'offset': 'int',
        'order_by_fields': 'list[str]',
        'scope': 'list[str]',
        'types': 'list[str]'
    }

    attribute_map = {
        'asset': 'asset',
        'filters': 'filters',
        'include_properties': 'includeProperties',
        'limit': 'limit',
        'offset': 'offset',
        'order_by_fields': 'orderByFields',
        'scope': 'scope',
        'types': 'types'
    }

    def __init__(self, asset=None, filters=None, include_properties=None, limit=40, offset=0, order_by_fields=None, scope=None, types=None):
        """
        ItemSearchInputV1 - a model defined in Swagger
        """

        self._asset = None
        self._filters = None
        self._include_properties = None
        self._limit = None
        self._offset = None
        self._order_by_fields = None
        self._scope = None
        self._types = None

        if asset is not None:
          self.asset = asset
        if filters is not None:
          self.filters = filters
        if include_properties is not None:
          self.include_properties = include_properties
        if limit is not None:
          self.limit = limit
        if offset is not None:
          self.offset = offset
        if order_by_fields is not None:
          self.order_by_fields = order_by_fields
        if scope is not None:
          self.scope = scope
        if types is not None:
          self.types = types

    @property
    def asset(self):
        """
        Gets the asset of this ItemSearchInputV1.
        An ID that limits the results to items which are in the tree below the Asset referenced by the ID.

        :return: The asset of this ItemSearchInputV1.
        :rtype: str
        """
        return self._asset

    @asset.setter
    def asset(self, asset):
        """
        Sets the asset of this ItemSearchInputV1.
        An ID that limits the results to items which are in the tree below the Asset referenced by the ID.

        :param asset: The asset of this ItemSearchInputV1.
        :type: str
        """

        self._asset = asset

    @property
    def filters(self):
        """
        Gets the filters of this ItemSearchInputV1.
        A list of item filters to reduce the result set. To logical AND multiple filters, use <b>\"filter1 && filter2</b>\" on a single line. To logical OR multiple filters, put each onto a new line. Filters can include any of the following options:<br><b>Empty</b>: returns the first ceiling number of items<br><b>\"value\"</b>: name or description of the item contains the case-insensitive value<br><b>\"field==value\"</b>: specified field exactly matches the case-sensitive value or regex<br><b>\"field~=value\"</b>: specified field contains the case-insensitive value or case-sensitive regex<br>To search for all items in the desired scope you may also use \"\\*\" character as filter.<br><b>Example:</b> Find items where (name or description contains case-insensitive \"bulb\" AND description contains case-insensitive \"area a\") OR (items hosted by datasource \"Example Data\" where name exactly matches the regex \".\\*[ABC]_Temperature\")<br><b>bulb && Description~=area a</b><br><b>Datasource ID==Example Data && Name==/.\\*[ABC]_Temperature/</b><br>To allow items with the 'unsearchable' property to be returned, include <b>\"@includeUnsearchable\"</b> on its own line<br>To exclude globally scoped items when using the \"scope\" filter include <b>\"@excludeGloballyScoped\"</b> on its own line. own line. Use a type filter with only one item type for the best performance. Some combinations of item types are not allowed and must be split into separate searches.

        :return: The filters of this ItemSearchInputV1.
        :rtype: list[str]
        """
        return self._filters

    @filters.setter
    def filters(self, filters):
        """
        Sets the filters of this ItemSearchInputV1.
        A list of item filters to reduce the result set. To logical AND multiple filters, use <b>\"filter1 && filter2</b>\" on a single line. To logical OR multiple filters, put each onto a new line. Filters can include any of the following options:<br><b>Empty</b>: returns the first ceiling number of items<br><b>\"value\"</b>: name or description of the item contains the case-insensitive value<br><b>\"field==value\"</b>: specified field exactly matches the case-sensitive value or regex<br><b>\"field~=value\"</b>: specified field contains the case-insensitive value or case-sensitive regex<br>To search for all items in the desired scope you may also use \"\\*\" character as filter.<br><b>Example:</b> Find items where (name or description contains case-insensitive \"bulb\" AND description contains case-insensitive \"area a\") OR (items hosted by datasource \"Example Data\" where name exactly matches the regex \".\\*[ABC]_Temperature\")<br><b>bulb && Description~=area a</b><br><b>Datasource ID==Example Data && Name==/.\\*[ABC]_Temperature/</b><br>To allow items with the 'unsearchable' property to be returned, include <b>\"@includeUnsearchable\"</b> on its own line<br>To exclude globally scoped items when using the \"scope\" filter include <b>\"@excludeGloballyScoped\"</b> on its own line. own line. Use a type filter with only one item type for the best performance. Some combinations of item types are not allowed and must be split into separate searches.

        :param filters: The filters of this ItemSearchInputV1.
        :type: list[str]
        """

        self._filters = filters

    @property
    def include_properties(self):
        """
        Gets the include_properties of this ItemSearchInputV1.
        A list of one or more case-sensitive item properties to include in every item this search finds. Use a single entry set to <b>\"@allProperties\"</b> to specify that all item properties should be returned. Specified properties not present for an item are simply omitted and do not cause errors.

        :return: The include_properties of this ItemSearchInputV1.
        :rtype: list[str]
        """
        return self._include_properties

    @include_properties.setter
    def include_properties(self, include_properties):
        """
        Sets the include_properties of this ItemSearchInputV1.
        A list of one or more case-sensitive item properties to include in every item this search finds. Use a single entry set to <b>\"@allProperties\"</b> to specify that all item properties should be returned. Specified properties not present for an item are simply omitted and do not cause errors.

        :param include_properties: The include_properties of this ItemSearchInputV1.
        :type: list[str]
        """

        self._include_properties = include_properties

    @property
    def limit(self):
        """
        Gets the limit of this ItemSearchInputV1.
        The pagination limit, the total number of collection items that will be returned in this page of results. When using limit or offset values to query different item subsets it is important to sort the results using orderBy. Otherwise inconsistent results may be returned.

        :return: The limit of this ItemSearchInputV1.
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """
        Sets the limit of this ItemSearchInputV1.
        The pagination limit, the total number of collection items that will be returned in this page of results. When using limit or offset values to query different item subsets it is important to sort the results using orderBy. Otherwise inconsistent results may be returned.

        :param limit: The limit of this ItemSearchInputV1.
        :type: int
        """

        self._limit = limit

    @property
    def offset(self):
        """
        Gets the offset of this ItemSearchInputV1.
        The pagination offset, the index of the first collection item that will be returned in this page of results. When using limit or offset values to query different item subsets it is important to sort the results using orderBy. Otherwise inconsistent results may be returned.

        :return: The offset of this ItemSearchInputV1.
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """
        Sets the offset of this ItemSearchInputV1.
        The pagination offset, the index of the first collection item that will be returned in this page of results. When using limit or offset values to query different item subsets it is important to sort the results using orderBy. Otherwise inconsistent results may be returned.

        :param offset: The offset of this ItemSearchInputV1.
        :type: int
        """

        self._offset = offset

    @property
    def order_by_fields(self):
        """
        Gets the order_by_fields of this ItemSearchInputV1.
        An optional list of one or more fields used to sort the results.

        :return: The order_by_fields of this ItemSearchInputV1.
        :rtype: list[str]
        """
        return self._order_by_fields

    @order_by_fields.setter
    def order_by_fields(self, order_by_fields):
        """
        Sets the order_by_fields of this ItemSearchInputV1.
        An optional list of one or more fields used to sort the results.

        :param order_by_fields: The order_by_fields of this ItemSearchInputV1.
        :type: list[str]
        """

        self._order_by_fields = order_by_fields

    @property
    def scope(self):
        """
        Gets the scope of this ItemSearchInputV1.
        IDs that limit the results to those which are in the global scope or are scoped to the items referenced by the IDs. <br>The following item types can act as a scope: <b>Workbook</b><br>If the scope is set to the Empty GUID then the scoped items are excluded

        :return: The scope of this ItemSearchInputV1.
        :rtype: list[str]
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """
        Sets the scope of this ItemSearchInputV1.
        IDs that limit the results to those which are in the global scope or are scoped to the items referenced by the IDs. <br>The following item types can act as a scope: <b>Workbook</b><br>If the scope is set to the Empty GUID then the scoped items are excluded

        :param scope: The scope of this ItemSearchInputV1.
        :type: list[str]
        """

        self._scope = scope

    @property
    def types(self):
        """
        Gets the types of this ItemSearchInputV1.
        A list of one or more case-sensitive item types which will restrict results to only those items that exactly match, or are children of, one of the specified types. If no types are provided then items of any type are returned

        :return: The types of this ItemSearchInputV1.
        :rtype: list[str]
        """
        return self._types

    @types.setter
    def types(self, types):
        """
        Sets the types of this ItemSearchInputV1.
        A list of one or more case-sensitive item types which will restrict results to only those items that exactly match, or are children of, one of the specified types. If no types are provided then items of any type are returned

        :param types: The types of this ItemSearchInputV1.
        :type: list[str]
        """

        self._types = types

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ItemSearchInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class BatchArchiveContextLabelsInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'context_label_ids': 'list[str]',
        'table_id': 'str'
    }

    attribute_map = {
        'context_label_ids': 'contextLabelIds',
        'table_id': 'tableId'
    }

    def __init__(self, context_label_ids=None, table_id=None):
        """
        BatchArchiveContextLabelsInputV1 - a model defined in Swagger
        """

        self._context_label_ids = None
        self._table_id = None

        if context_label_ids is not None:
          self.context_label_ids = context_label_ids
        if table_id is not None:
          self.table_id = table_id

    @property
    def context_label_ids(self):
        """
        Gets the context_label_ids of this BatchArchiveContextLabelsInputV1.
        List of context label IDs to archive

        :return: The context_label_ids of this BatchArchiveContextLabelsInputV1.
        :rtype: list[str]
        """
        return self._context_label_ids

    @context_label_ids.setter
    def context_label_ids(self, context_label_ids):
        """
        Sets the context_label_ids of this BatchArchiveContextLabelsInputV1.
        List of context label IDs to archive

        :param context_label_ids: The context_label_ids of this BatchArchiveContextLabelsInputV1.
        :type: list[str]
        """

        self._context_label_ids = context_label_ids

    @property
    def table_id(self):
        """
        Gets the table_id of this BatchArchiveContextLabelsInputV1.
        If provided, the ID of the Table Definition that will be used for permissions checking. The user needs read permissions on the provided table definition and theitem has to be in the table in order to create, update, or delete context. If not provided, the user must have read permissions on the item id the context is being applied to.

        :return: The table_id of this BatchArchiveContextLabelsInputV1.
        :rtype: str
        """
        return self._table_id

    @table_id.setter
    def table_id(self, table_id):
        """
        Sets the table_id of this BatchArchiveContextLabelsInputV1.
        If provided, the ID of the Table Definition that will be used for permissions checking. The user needs read permissions on the provided table definition and theitem has to be in the table in order to create, update, or delete context. If not provided, the user must have read permissions on the item id the context is being applied to.

        :param table_id: The table_id of this BatchArchiveContextLabelsInputV1.
        :type: str
        """

        self._table_id = table_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, BatchArchiveContextLabelsInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class DatasourcesApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def archive_datasource(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def archive_datasource_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def clean_up(
        self,
        **kwargs: Any,
    ) -> DatasourceCleanUpOutputV1: ...

    def clean_up_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def clear_datasource_cache(
        self,
        **kwargs: Any,
    ) -> DatasourceCacheClearOutputV1: ...

    def clear_datasource_cache_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_datasource(
        self,
        **kwargs: Any,
    ) -> DatasourceOutputV1: ...

    def create_datasource_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def disable_connections(
        self,
        **kwargs: Any,
    ) -> ConnectionsOutputV1: ...

    def disable_connections_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def fully_archive_datasource(
        self,
        **kwargs: Any,
    ) -> JobAcceptedOutputV1: ...

    def fully_archive_datasource_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_datasource(
        self,
        **kwargs: Any,
    ) -> DatasourceOutputV1: ...

    def get_datasource_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_datasources(
        self,
        **kwargs: Any,
    ) -> DatasourceOutputListV1: ...

    def get_datasources_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_items_hosted_by_datasource(
        self,
        **kwargs: Any,
    ) -> ItemPreviewListV1: ...

    def get_items_hosted_by_datasource_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_precached_items(
        self,
        **kwargs: Any,
    ) -> PrecachedItemsOutputV1: ...

    def get_precached_items_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_status(
        self,
        **kwargs: Any,
    ) -> DatasourceStatusOutputV1: ...

    def get_status_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def recount(
        self,
        **kwargs: Any,
    ) -> DatasourceOutputV1: ...

    def recount_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class BoardOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _applied_filter: Optional[str]
    _archived: Optional[bool]
    _background_color: Optional[str]
    _columns: int
    _created_at: Optional[str]
    _description: Optional[str]
    _enabled: Optional[bool]
    _end_date: Optional[str]
    _filters: List[BoardFilterOutputV1]
    _id: str
    _locked: Optional[bool]
    _name: str
    _row_height: int
    _scoped_to: Optional[str]
    _start_date: Optional[str]
    _tiles: List[TileOutputV1]
    _timezone: str
    _updated_at: Optional[str]


    def __init__(
        self,
        applied_filter: Optional[str] = None,
        archived: Optional[bool] = None,
        background_color: Optional[str] = None,
        columns: Optional[int] = None,
        created_at: Optional[str] = None,
        description: Optional[str] = None,
        enabled: Optional[bool] = None,
        end_date: Optional[str] = None,
        filters: Optional[List[BoardFilterOutputV1]] = None,
        id: Optional[str] = None,
        locked: Optional[bool] = None,
        name: Optional[str] = None,
        row_height: Optional[int] = None,
        scoped_to: Optional[str] = None,
        start_date: Optional[str] = None,
        tiles: Optional[List[TileOutputV1]] = None,
        timezone: Optional[str] = None,
        updated_at: Optional[str] = None,
    ) -> None: ...

    @property
    def applied_filter(self) -> Optional[str]: ...

    @applied_filter.setter
    def applied_filter(self, applied_filter: Optional[str]) -> None: ...

    @property
    def archived(self) -> Optional[bool]: ...

    @archived.setter
    def archived(self, archived: Optional[bool]) -> None: ...

    @property
    def background_color(self) -> Optional[str]: ...

    @background_color.setter
    def background_color(self, background_color: Optional[str]) -> None: ...

    @property
    def columns(self) -> int: ...

    @columns.setter
    def columns(self, columns: int) -> None: ...

    @property
    def created_at(self) -> Optional[str]: ...

    @created_at.setter
    def created_at(self, created_at: Optional[str]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def enabled(self) -> Optional[bool]: ...

    @enabled.setter
    def enabled(self, enabled: Optional[bool]) -> None: ...

    @property
    def end_date(self) -> Optional[str]: ...

    @end_date.setter
    def end_date(self, end_date: Optional[str]) -> None: ...

    @property
    def filters(self) -> List[BoardFilterOutputV1]: ...

    @filters.setter
    def filters(self, filters: List[BoardFilterOutputV1]) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def locked(self) -> Optional[bool]: ...

    @locked.setter
    def locked(self, locked: Optional[bool]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def row_height(self) -> int: ...

    @row_height.setter
    def row_height(self, row_height: int) -> None: ...

    @property
    def scoped_to(self) -> Optional[str]: ...

    @scoped_to.setter
    def scoped_to(self, scoped_to: Optional[str]) -> None: ...

    @property
    def start_date(self) -> Optional[str]: ...

    @start_date.setter
    def start_date(self, start_date: Optional[str]) -> None: ...

    @property
    def tiles(self) -> List[TileOutputV1]: ...

    @tiles.setter
    def tiles(self, tiles: List[TileOutputV1]) -> None: ...

    @property
    def timezone(self) -> str: ...

    @timezone.setter
    def timezone(self, timezone: str) -> None: ...

    @property
    def updated_at(self) -> Optional[str]: ...

    @updated_at.setter
    def updated_at(self, updated_at: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class ItemsApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def add_access_control_entry(
        self,
        **kwargs: Any,
    ) -> AclOutputV1: ...

    def add_access_control_entry_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def archive_item(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def archive_item_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def archive_item_finder(
        self,
        **kwargs: Any,
    ) -> ArchiveOutputV1: ...

    def archive_item_finder_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def change_owner(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def change_owner_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def clear_cache(
        self,
        **kwargs: Any,
    ) -> CacheInfoV1: ...

    def clear_cache_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_context_condition(
        self,
        **kwargs: Any,
    ) -> ConditionOutputV1: ...

    def create_context_condition_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_item_finder(
        self,
        **kwargs: Any,
    ) -> ItemFinderOutputV1: ...

    def create_item_finder_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_property(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def delete_property_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def execute_item_finder(
        self,
        **kwargs: Any,
    ) -> ItemFinderOutputV1: ...

    def execute_item_finder_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def execute_item_finder_searches(
        self,
        **kwargs: Any,
    ) -> ItemFinderSearchesOutputV1: ...

    def execute_item_finder_searches_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def find_swap(
        self,
        **kwargs: Any,
    ) -> ItemPreviewV1: ...

    def find_swap_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_access_control(
        self,
        **kwargs: Any,
    ) -> AclOutputV1: ...

    def get_access_control_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_access_control_details(
        self,
        **kwargs: Any,
    ) -> AclOutputV1: ...

    def get_access_control_details_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_context_condition(
        self,
        **kwargs: Any,
    ) -> ConditionOutputV1: ...

    def get_context_condition_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_formula_dependencies(
        self,
        **kwargs: Any,
    ) -> ItemDependencyOutputV1: ...

    def get_formula_dependencies_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_formula_dependents(
        self,
        **kwargs: Any,
    ) -> ItemPreviewListV1: ...

    def get_formula_dependents_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_interested(
        self,
        **kwargs: Any,
    ) -> ItemPreviewListV1: ...

    def get_interested_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_item_and_all_properties(
        self,
        **kwargs: Any,
    ) -> ItemOutputV1: ...

    def get_item_and_all_properties_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_item_finder(
        self,
        **kwargs: Any,
    ) -> ItemFinderOutputV1: ...

    def get_item_finder_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_item_finders(
        self,
        **kwargs: Any,
    ) -> ItemFinderOutputListV1: ...

    def get_item_finders_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_item_preview(
        self,
        **kwargs: Any,
    ) -> ItemSearchPreviewV1: ...

    def get_item_preview_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_item_usages(
        self,
        **kwargs: Any,
    ) -> ItemPreviewListV1: ...

    def get_item_usages_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_item_user_attributes(
        self,
        **kwargs: Any,
    ) -> ItemUserAttributesOutputV1: ...

    def get_item_user_attributes_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_parent_datasources(
        self,
        **kwargs: Any,
    ) -> DatasourcePairsOutputV1: ...

    def get_parent_datasources_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_pinned_items(
        self,
        **kwargs: Any,
    ) -> ItemSearchPreviewListV1: ...

    def get_pinned_items_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_property(
        self,
        **kwargs: Any,
    ) -> PropertyOutputV1: ...

    def get_property_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_stored_table_search_failures(
        self,
        **kwargs: Any,
    ) -> StoredTableSearchFailureOutputListV1: ...

    def get_stored_table_search_failures_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_swap_options(
        self,
        **kwargs: Any,
    ) -> SwapOptionListV1: ...

    def get_swap_options_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def lock_item(
        self,
        **kwargs: Any,
    ) -> LockedItemListOutputV1: ...

    def lock_item_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def pin_item(
        self,
        **kwargs: Any,
    ) -> ItemSearchPreviewListV1: ...

    def pin_item_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def remove_access_control_entry(
        self,
        **kwargs: Any,
    ) -> AclOutputV1: ...

    def remove_access_control_entry_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def reset_cdc(
        self,
        **kwargs: Any,
    ) -> PropertyOutputV1: ...

    def reset_cdc_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def search_items(
        self,
        **kwargs: Any,
    ) -> ItemSearchPreviewPaginatedListV1: ...

    def search_items_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def search_items_post(
        self,
        **kwargs: Any,
    ) -> ItemSearchPreviewPaginatedListV1: ...

    def search_items_post_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def set_acl(
        self,
        **kwargs: Any,
    ) -> AclOutputV1: ...

    def set_acl_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def set_acl_inheritance(
        self,
        **kwargs: Any,
    ) -> AclOutputV1: ...

    def set_acl_inheritance_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def set_formula(
        self,
        **kwargs: Any,
    ) -> CalculatedItemOutputV1: ...

    def set_formula_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def set_item_user_attributes(
        self,
        **kwargs: Any,
    ) -> ItemUserAttributesOutputV1: ...

    def set_item_user_attributes_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def set_properties(
        self,
        **kwargs: Any,
    ) -> ItemOutputV1: ...

    def set_properties_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def set_property(
        self,
        **kwargs: Any,
    ) -> PropertyHrefOutputV1: ...

    def set_property_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def set_scope(
        self,
        **kwargs: Any,
    ) -> ItemOutputV1: ...

    def set_scope_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def unpin_item(
        self,
        **kwargs: Any,
    ) -> ItemSearchPreviewListV1: ...

    def unpin_item_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_item_finder(
        self,
        **kwargs: Any,
    ) -> ItemFinderOutputV1: ...

    def update_item_finder_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def validate_item_lockability(
        self,
        **kwargs: Any,
    ) -> LockErrorsOutputV1: ...

    def validate_item_lockability_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class ProjectsApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def add_schedule_notebook_result(
        self,
        **kwargs: Any,
    ) -> ScheduledNotebookOutputV1: ...

    def add_schedule_notebook_result_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def archive_project(
        self,
        **kwargs: Any,
    ) -> ArchiveOutputV1: ...

    def archive_project_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_project(
        self,
        **kwargs: Any,
    ) -> ProjectOutputV1: ...

    def create_project_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_project(
        self,
        **kwargs: Any,
    ) -> ProjectOutputV1: ...

    def get_project_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_projects(
        self,
        **kwargs: Any,
    ) -> GetProjectsOutputV1: ...

    def get_projects_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_scheduled_notebook(
        self,
        **kwargs: Any,
    ) -> ScheduledNotebookOutputV1: ...

    def get_scheduled_notebook_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_scheduled_notebooks(
        self,
        **kwargs: Any,
    ) -> ScheduledNotebookListOutputV1: ...

    def get_scheduled_notebooks_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def put_project(
        self,
        **kwargs: Any,
    ) -> ProjectOutputV1: ...

    def put_project_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def schedule_notebook(
        self,
        **kwargs: Any,
    ) -> ScheduledNotebookOutputV1: ...

    def schedule_notebook_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def unschedule_notebook(
        self,
        **kwargs: Any,
    ) -> ScheduledNotebookListOutputV1: ...

    def unschedule_notebook_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class HierarchyNodeOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'column_id': 'str',
        'display_name': 'str',
        'item_metadata': 'ItemMetadata',
        'leaf': 'bool'
    }

    attribute_map = {
        'column_id': 'columnId',
        'display_name': 'displayName',
        'item_metadata': 'itemMetadata',
        'leaf': 'leaf'
    }

    def __init__(self, column_id=None, display_name=None, item_metadata=None, leaf=None):
        """
        HierarchyNodeOutputV1 - a model defined in Swagger
        """

        self._column_id = None
        self._display_name = None
        self._item_metadata = None
        self._leaf = None

        if column_id is not None:
          self.column_id = column_id
        if display_name is not None:
          self.display_name = display_name
        if item_metadata is not None:
          self.item_metadata = item_metadata
        if leaf is not None:
          self.leaf = leaf

    @property
    def column_id(self):
        """
        Gets the column_id of this HierarchyNodeOutputV1.
        The ID of the Item Table ColumnDefinition whose value generated this node.

        :return: The column_id of this HierarchyNodeOutputV1.
        :rtype: str
        """
        return self._column_id

    @column_id.setter
    def column_id(self, column_id):
        """
        Sets the column_id of this HierarchyNodeOutputV1.
        The ID of the Item Table ColumnDefinition whose value generated this node.

        :param column_id: The column_id of this HierarchyNodeOutputV1.
        :type: str
        """
        if column_id is None:
            raise ValueError("Invalid value for `column_id`, must not be `None`")

        self._column_id = column_id

    @property
    def display_name(self):
        """
        Gets the display_name of this HierarchyNodeOutputV1.
        The display name of the hierarchy node.

        :return: The display_name of this HierarchyNodeOutputV1.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this HierarchyNodeOutputV1.
        The display name of the hierarchy node.

        :param display_name: The display_name of this HierarchyNodeOutputV1.
        :type: str
        """
        if display_name is None:
            raise ValueError("Invalid value for `display_name`, must not be `None`")

        self._display_name = display_name

    @property
    def item_metadata(self):
        """
        Gets the item_metadata of this HierarchyNodeOutputV1.

        :return: The item_metadata of this HierarchyNodeOutputV1.
        :rtype: ItemMetadata
        """
        return self._item_metadata

    @item_metadata.setter
    def item_metadata(self, item_metadata):
        """
        Sets the item_metadata of this HierarchyNodeOutputV1.

        :param item_metadata: The item_metadata of this HierarchyNodeOutputV1.
        :type: ItemMetadata
        """

        self._item_metadata = item_metadata

    @property
    def leaf(self):
        """
        Gets the leaf of this HierarchyNodeOutputV1.
        Whether or not this node is a leaf in its hierarchy.

        :return: The leaf of this HierarchyNodeOutputV1.
        :rtype: bool
        """
        return self._leaf

    @leaf.setter
    def leaf(self, leaf):
        """
        Sets the leaf of this HierarchyNodeOutputV1.
        Whether or not this node is a leaf in its hierarchy.

        :param leaf: The leaf of this HierarchyNodeOutputV1.
        :type: bool
        """
        if leaf is None:
            raise ValueError("Invalid value for `leaf`, must not be `None`")

        self._leaf = leaf

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, HierarchyNodeOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class AuditOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _affected_items: List[str]
    _after_summary: str
    _before_summary: str
    _change_type: str
    _item_id: str
    _item_name: str
    _item_type: str
    _time_stamp: str
    _user_id: str
    _user_name: str


    def __init__(
        self,
        affected_items: Optional[List[str]] = None,
        after_summary: Optional[str] = None,
        before_summary: Optional[str] = None,
        change_type: Optional[str] = None,
        item_id: Optional[str] = None,
        item_name: Optional[str] = None,
        item_type: Optional[str] = None,
        time_stamp: Optional[str] = None,
        user_id: Optional[str] = None,
        user_name: Optional[str] = None,
    ) -> None: ...

    @property
    def affected_items(self) -> List[str]: ...

    @affected_items.setter
    def affected_items(self, affected_items: List[str]) -> None: ...

    @property
    def after_summary(self) -> str: ...

    @after_summary.setter
    def after_summary(self, after_summary: str) -> None: ...

    @property
    def before_summary(self) -> str: ...

    @before_summary.setter
    def before_summary(self, before_summary: str) -> None: ...

    @property
    def change_type(self) -> str: ...

    @change_type.setter
    def change_type(self, change_type: str) -> None: ...

    @property
    def item_id(self) -> str: ...

    @item_id.setter
    def item_id(self, item_id: str) -> None: ...

    @property
    def item_name(self) -> str: ...

    @item_name.setter
    def item_name(self, item_name: str) -> None: ...

    @property
    def item_type(self) -> str: ...

    @item_type.setter
    def item_type(self, item_type: str) -> None: ...

    @property
    def time_stamp(self) -> str: ...

    @time_stamp.setter
    def time_stamp(self, time_stamp: str) -> None: ...

    @property
    def user_id(self) -> str: ...

    @user_id.setter
    def user_id(self, user_id: str) -> None: ...

    @property
    def user_name(self) -> str: ...

    @user_name.setter
    def user_name(self, user_name: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class BoardTileGetInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'applied_filters': 'list[BoardFilterInputV1]',
        'end_date': 'str',
        'start_date': 'str'
    }

    attribute_map = {
        'applied_filters': 'appliedFilters',
        'end_date': 'endDate',
        'start_date': 'startDate'
    }

    def __init__(self, applied_filters=None, end_date=None, start_date=None):
        """
        BoardTileGetInputV1 - a model defined in Swagger
        """

        self._applied_filters = None
        self._end_date = None
        self._start_date = None

        if applied_filters is not None:
          self.applied_filters = applied_filters
        if end_date is not None:
          self.end_date = end_date
        if start_date is not None:
          self.start_date = start_date

    @property
    def applied_filters(self):
        """
        Gets the applied_filters of this BoardTileGetInputV1.
        Filters to apply to the board and tile data

        :return: The applied_filters of this BoardTileGetInputV1.
        :rtype: list[BoardFilterInputV1]
        """
        return self._applied_filters

    @applied_filters.setter
    def applied_filters(self, applied_filters):
        """
        Sets the applied_filters of this BoardTileGetInputV1.
        Filters to apply to the board and tile data

        :param applied_filters: The applied_filters of this BoardTileGetInputV1.
        :type: list[BoardFilterInputV1]
        """

        self._applied_filters = applied_filters

    @property
    def end_date(self):
        """
        Gets the end_date of this BoardTileGetInputV1.
        The end date for the date range of the data

        :return: The end_date of this BoardTileGetInputV1.
        :rtype: str
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """
        Sets the end_date of this BoardTileGetInputV1.
        The end date for the date range of the data

        :param end_date: The end_date of this BoardTileGetInputV1.
        :type: str
        """

        self._end_date = end_date

    @property
    def start_date(self):
        """
        Gets the start_date of this BoardTileGetInputV1.
        The start date for the date range of the data

        :return: The start_date of this BoardTileGetInputV1.
        :rtype: str
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """
        Sets the start_date of this BoardTileGetInputV1.
        The start date for the date range of the data

        :param start_date: The start_date of this BoardTileGetInputV1.
        :type: str
        """

        self._start_date = start_date

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, BoardTileGetInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class CalculatedTableOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _archived: Optional[bool]
    _column_dependencies: Optional[List[CalculatedTableColumnDependencyOutputV1]]
    _column_metadata: Optional[List[CalculatedTableColumnMetadataOutputV1]]
    _created_at: Optional[str]
    _creator_id: Optional[str]
    _description: Optional[str]
    _id: Optional[str]
    _locked: Optional[bool]
    _name: Optional[str]
    _owner_id: Optional[str]
    _query: Optional[str]
    _scoped_to: Optional[str]
    _updated_at: Optional[str]


    def __init__(
        self,
        archived: Optional[bool] = None,
        column_dependencies: Optional[List[CalculatedTableColumnDependencyOutputV1]] = None,
        column_metadata: Optional[List[CalculatedTableColumnMetadataOutputV1]] = None,
        created_at: Optional[str] = None,
        creator_id: Optional[str] = None,
        description: Optional[str] = None,
        id: Optional[str] = None,
        locked: Optional[bool] = None,
        name: Optional[str] = None,
        owner_id: Optional[str] = None,
        query: Optional[str] = None,
        scoped_to: Optional[str] = None,
        updated_at: Optional[str] = None,
    ) -> None: ...

    @property
    def archived(self) -> Optional[bool]: ...

    @archived.setter
    def archived(self, archived: Optional[bool]) -> None: ...

    @property
    def column_dependencies(self) -> Optional[List[CalculatedTableColumnDependencyOutputV1]]: ...

    @column_dependencies.setter
    def column_dependencies(self, column_dependencies: Optional[List[CalculatedTableColumnDependencyOutputV1]]) -> None: ...

    @property
    def column_metadata(self) -> Optional[List[CalculatedTableColumnMetadataOutputV1]]: ...

    @column_metadata.setter
    def column_metadata(self, column_metadata: Optional[List[CalculatedTableColumnMetadataOutputV1]]) -> None: ...

    @property
    def created_at(self) -> Optional[str]: ...

    @created_at.setter
    def created_at(self, created_at: Optional[str]) -> None: ...

    @property
    def creator_id(self) -> Optional[str]: ...

    @creator_id.setter
    def creator_id(self, creator_id: Optional[str]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def id(self) -> Optional[str]: ...

    @id.setter
    def id(self, id: Optional[str]) -> None: ...

    @property
    def locked(self) -> Optional[bool]: ...

    @locked.setter
    def locked(self, locked: Optional[bool]) -> None: ...

    @property
    def name(self) -> Optional[str]: ...

    @name.setter
    def name(self, name: Optional[str]) -> None: ...

    @property
    def owner_id(self) -> Optional[str]: ...

    @owner_id.setter
    def owner_id(self, owner_id: Optional[str]) -> None: ...

    @property
    def query(self) -> Optional[str]: ...

    @query.setter
    def query(self, query: Optional[str]) -> None: ...

    @property
    def scoped_to(self) -> Optional[str]: ...

    @scoped_to.setter
    def scoped_to(self, scoped_to: Optional[str]) -> None: ...

    @property
    def updated_at(self) -> Optional[str]: ...

    @updated_at.setter
    def updated_at(self, updated_at: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class SentEmailOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _attachments: List[SentEmailAttachmentOutputV1]
    _bcc_emails: List[str]
    _cc_emails: List[str]
    _content: str
    _id: str
    _response_code: int
    _response_message: Optional[str]
    _sender: Optional[ItemPreviewV1]
    _sent_at: str
    _source: Optional[ItemPreviewV1]
    _subject: str
    _to_emails: List[str]


    def __init__(
        self,
        attachments: Optional[List[SentEmailAttachmentOutputV1]] = None,
        bcc_emails: Optional[List[str]] = None,
        cc_emails: Optional[List[str]] = None,
        content: Optional[str] = None,
        id: Optional[str] = None,
        response_code: Optional[int] = None,
        response_message: Optional[str] = None,
        sender: Optional[ItemPreviewV1] = None,
        sent_at: Optional[str] = None,
        source: Optional[ItemPreviewV1] = None,
        subject: Optional[str] = None,
        to_emails: Optional[List[str]] = None,
    ) -> None: ...

    @property
    def attachments(self) -> List[SentEmailAttachmentOutputV1]: ...

    @attachments.setter
    def attachments(self, attachments: List[SentEmailAttachmentOutputV1]) -> None: ...

    @property
    def bcc_emails(self) -> List[str]: ...

    @bcc_emails.setter
    def bcc_emails(self, bcc_emails: List[str]) -> None: ...

    @property
    def cc_emails(self) -> List[str]: ...

    @cc_emails.setter
    def cc_emails(self, cc_emails: List[str]) -> None: ...

    @property
    def content(self) -> str: ...

    @content.setter
    def content(self, content: str) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def response_code(self) -> int: ...

    @response_code.setter
    def response_code(self, response_code: int) -> None: ...

    @property
    def response_message(self) -> Optional[str]: ...

    @response_message.setter
    def response_message(self, response_message: Optional[str]) -> None: ...

    @property
    def sender(self) -> Optional[ItemPreviewV1]: ...

    @sender.setter
    def sender(self, sender: Optional[ItemPreviewV1]) -> None: ...

    @property
    def sent_at(self) -> str: ...

    @sent_at.setter
    def sent_at(self, sent_at: str) -> None: ...

    @property
    def source(self) -> Optional[ItemPreviewV1]: ...

    @source.setter
    def source(self, source: Optional[ItemPreviewV1]) -> None: ...

    @property
    def subject(self) -> str: ...

    @subject.setter
    def subject(self, subject: str) -> None: ...

    @property
    def to_emails(self) -> List[str]: ...

    @to_emails.setter
    def to_emails(self, to_emails: List[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class AnnotationInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _backup_name: Optional[str]
    _created_by_id: Optional[str]
    _description: Optional[str]
    _discoverable: Optional[bool]
    _document: Optional[str]
    _interests: Optional[List[AnnotationInterestInputV1]]
    _name: str
    _replies_to: Optional[str]
    _report_input: Optional[OptionalReportInputV1]
    _type: Optional[str]


    def __init__(
        self,
        backup_name: Optional[str] = None,
        created_by_id: Optional[str] = None,
        description: Optional[str] = None,
        discoverable: Optional[bool] = None,
        document: Optional[str] = None,
        interests: Optional[List[AnnotationInterestInputV1]] = None,
        name: Optional[str] = None,
        replies_to: Optional[str] = None,
        report_input: Optional[OptionalReportInputV1] = None,
        type: Optional[str] = None,
    ) -> None: ...

    @property
    def backup_name(self) -> Optional[str]: ...

    @backup_name.setter
    def backup_name(self, backup_name: Optional[str]) -> None: ...

    @property
    def created_by_id(self) -> Optional[str]: ...

    @created_by_id.setter
    def created_by_id(self, created_by_id: Optional[str]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def discoverable(self) -> Optional[bool]: ...

    @discoverable.setter
    def discoverable(self, discoverable: Optional[bool]) -> None: ...

    @property
    def document(self) -> Optional[str]: ...

    @document.setter
    def document(self, document: Optional[str]) -> None: ...

    @property
    def interests(self) -> Optional[List[AnnotationInterestInputV1]]: ...

    @interests.setter
    def interests(self, interests: Optional[List[AnnotationInterestInputV1]]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def replies_to(self) -> Optional[str]: ...

    @replies_to.setter
    def replies_to(self, replies_to: Optional[str]) -> None: ...

    @property
    def report_input(self) -> Optional[OptionalReportInputV1]: ...

    @report_input.setter
    def report_input(self, report_input: Optional[OptionalReportInputV1]) -> None: ...

    @property
    def type(self) -> Optional[str]: ...

    @type.setter
    def type(self, type: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class CustomAgentRevisionOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_at': 'str',
        'created_by': 'str',
        'created_by_id': 'str',
        'id': 'str',
        'name': 'str',
        'type': 'str',
        'updated_at': 'str'
    }

    attribute_map = {
        'created_at': 'createdAt',
        'created_by': 'createdBy',
        'created_by_id': 'createdById',
        'id': 'id',
        'name': 'name',
        'type': 'type',
        'updated_at': 'updatedAt'
    }

    def __init__(self, created_at=None, created_by=None, created_by_id=None, id=None, name=None, type=None, updated_at=None):
        """
        CustomAgentRevisionOutputV1 - a model defined in Swagger
        """

        self._created_at = None
        self._created_by = None
        self._created_by_id = None
        self._id = None
        self._name = None
        self._type = None
        self._updated_at = None

        if created_at is not None:
          self.created_at = created_at
        if created_by is not None:
          self.created_by = created_by
        if created_by_id is not None:
          self.created_by_id = created_by_id
        if id is not None:
          self.id = id
        if name is not None:
          self.name = name
        if type is not None:
          self.type = type
        if updated_at is not None:
          self.updated_at = updated_at

    @property
    def created_at(self):
        """
        Gets the created_at of this CustomAgentRevisionOutputV1.
        The time the workflow revision was created

        :return: The created_at of this CustomAgentRevisionOutputV1.
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """
        Sets the created_at of this CustomAgentRevisionOutputV1.
        The time the workflow revision was created

        :param created_at: The created_at of this CustomAgentRevisionOutputV1.
        :type: str
        """
        if created_at is None:
            raise ValueError("Invalid value for `created_at`, must not be `None`")

        self._created_at = created_at

    @property
    def created_by(self):
        """
        Gets the created_by of this CustomAgentRevisionOutputV1.
        The username of the workflow revision creator (if available)

        :return: The created_by of this CustomAgentRevisionOutputV1.
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this CustomAgentRevisionOutputV1.
        The username of the workflow revision creator (if available)

        :param created_by: The created_by of this CustomAgentRevisionOutputV1.
        :type: str
        """

        self._created_by = created_by

    @property
    def created_by_id(self):
        """
        Gets the created_by_id of this CustomAgentRevisionOutputV1.
        The item ID of the workflow revision creator (if available)

        :return: The created_by_id of this CustomAgentRevisionOutputV1.
        :rtype: str
        """
        return self._created_by_id

    @created_by_id.setter
    def created_by_id(self, created_by_id):
        """
        Sets the created_by_id of this CustomAgentRevisionOutputV1.
        The item ID of the workflow revision creator (if available)

        :param created_by_id: The created_by_id of this CustomAgentRevisionOutputV1.
        :type: str
        """

        self._created_by_id = created_by_id

    @property
    def id(self):
        """
        Gets the id of this CustomAgentRevisionOutputV1.
        The workflow revision item ID

        :return: The id of this CustomAgentRevisionOutputV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this CustomAgentRevisionOutputV1.
        The workflow revision item ID

        :param id: The id of this CustomAgentRevisionOutputV1.
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id

    @property
    def name(self):
        """
        Gets the name of this CustomAgentRevisionOutputV1.
        The workflow revision item name

        :return: The name of this CustomAgentRevisionOutputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CustomAgentRevisionOutputV1.
        The workflow revision item name

        :param name: The name of this CustomAgentRevisionOutputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def type(self):
        """
        Gets the type of this CustomAgentRevisionOutputV1.
        The workflow revision item type

        :return: The type of this CustomAgentRevisionOutputV1.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this CustomAgentRevisionOutputV1.
        The workflow revision item type

        :param type: The type of this CustomAgentRevisionOutputV1.
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")

        self._type = type

    @property
    def updated_at(self):
        """
        Gets the updated_at of this CustomAgentRevisionOutputV1.
        The last time the workflow revision was updated

        :return: The updated_at of this CustomAgentRevisionOutputV1.
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """
        Sets the updated_at of this CustomAgentRevisionOutputV1.
        The last time the workflow revision was updated

        :param updated_at: The updated_at of this CustomAgentRevisionOutputV1.
        :type: str
        """
        if updated_at is None:
            raise ValueError("Invalid value for `updated_at`, must not be `None`")

        self._updated_at = updated_at

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, CustomAgentRevisionOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class WorkbooksApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def add_recently_accessed(
        self,
        **kwargs: Any,
    ) -> ItemSearchPreviewListV1: ...

    def add_recently_accessed_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def archive_workbook(
        self,
        **kwargs: Any,
    ) -> ArchiveOutputV1: ...

    def archive_workbook_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def archive_worksheet(
        self,
        **kwargs: Any,
    ) -> ArchiveOutputV1: ...

    def archive_worksheet_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_sandbox(
        self,
        **kwargs: Any,
    ) -> WorksheetOutputV1: ...

    def create_sandbox_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_workbook(
        self,
        **kwargs: Any,
    ) -> WorkbookOutputV1: ...

    def create_workbook_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_worksheet(
        self,
        **kwargs: Any,
    ) -> WorksheetOutputV1: ...

    def create_worksheet_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_worksheet_thumbnail(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def create_worksheet_thumbnail_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_workstep(
        self,
        **kwargs: Any,
    ) -> WorkstepOutputV1: ...

    def create_workstep_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_recently_accessed(
        self,
        **kwargs: Any,
    ) -> ItemSearchPreviewListV1: ...

    def get_recently_accessed_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_referenced_items(
        self,
        **kwargs: Any,
    ) -> ReferencedItemsOutputV1: ...

    def get_referenced_items_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_workbook(
        self,
        **kwargs: Any,
    ) -> WorkbookOutputV1: ...

    def get_workbook_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_workbook_owner(
        self,
        **kwargs: Any,
    ) -> WorkbookOwnerOutputV1: ...

    def get_workbook_owner_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_workbooks(
        self,
        **kwargs: Any,
    ) -> WorkbookOutputListV1: ...

    def get_workbooks_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_worksheet(
        self,
        **kwargs: Any,
    ) -> WorksheetOutputV1: ...

    def get_worksheet_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_worksheet_thumbnail(
        self,
        **kwargs: Any,
    ) -> bytes: ...

    def get_worksheet_thumbnail_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_worksheet_usages(
        self,
        **kwargs: Any,
    ) -> AnnotationListOutputV1: ...

    def get_worksheet_usages_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_worksheets(
        self,
        **kwargs: Any,
    ) -> WorksheetOutputListV1: ...

    def get_worksheets_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_workstep(
        self,
        **kwargs: Any,
    ) -> WorkstepOutputV1: ...

    def get_workstep_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_workstep_by_id(
        self,
        **kwargs: Any,
    ) -> WorkstepOutputV1: ...

    def get_workstep_by_id_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_worksteps(
        self,
        **kwargs: Any,
    ) -> WorkstepChronologyOutputV1: ...

    def get_worksteps_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def move_worksheet(
        self,
        **kwargs: Any,
    ) -> WorksheetOutputV1: ...

    def move_worksheet_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def set_current_workstep(
        self,
        **kwargs: Any,
    ) -> WorkstepOutputV1: ...

    def set_current_workstep_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def set_renderer(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def set_renderer_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class UsersApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def autocomplete_users_and_groups(
        self,
        **kwargs: Any,
    ) -> IdentityPreviewListV1: ...

    def autocomplete_users_and_groups_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_user(
        self,
        **kwargs: Any,
    ) -> UserOutputV1: ...

    def create_user_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_user(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def delete_user_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_items_shared_with_identity(
        self,
        **kwargs: Any,
    ) -> ItemPreviewListV1: ...

    def get_items_shared_with_identity_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_items_shared_with_me(
        self,
        **kwargs: Any,
    ) -> ItemPreviewListV1: ...

    def get_items_shared_with_me_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_me(
        self,
        **kwargs: Any,
    ) -> UserOutputV1: ...

    def get_me_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_user(
        self,
        **kwargs: Any,
    ) -> UserOutputV1: ...

    def get_user_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_user_from_username(
        self,
        **kwargs: Any,
    ) -> UserOutputV1: ...

    def get_user_from_username_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_users(
        self,
        **kwargs: Any,
    ) -> UserOutputListV1: ...

    def get_users_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def set_trust(
        self,
        **kwargs: Any,
    ) -> UserOutputV1: ...

    def set_trust_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_password(
        self,
        **kwargs: Any,
    ) -> UserOutputV1: ...

    def update_password_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_user(
        self,
        **kwargs: Any,
    ) -> UserOutputV1: ...

    def update_user_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, Optional


class ClientConfiguration(object):
    DEFAULT_RETRY_TIMEOUT_IN_SECONDS: int
    DEFAULT_REQUEST_TIMEOUT_IN_SECONDS: Optional[int]

    host: str
    api_client: Any

    api_key: Dict[str, str]
    api_key_prefix: Dict[str, str]
    username: str
    password: str

    verify_ssl: bool
    ssl_ca_cert: Optional[str]
    cert_file: Optional[str]
    key_file: Optional[str]
    assert_hostname: Any

    proxy: Optional[str]

    retry_timeout_in_seconds: int
    request_timeout_in_seconds: Optional[int]

    client_side_validation: bool

    @staticmethod
    def get_default_instance() -> ClientConfiguration: ...

    def __init__(self) -> None: ...

    def get_api_key_with_prefix(self, identifier: str) -> Optional[str]: ...
    def get_basic_auth_token(self) -> str: ...

    def set_default(self, default: Optional[ClientConfiguration] = None) -> None: ...

    def set_identity_path(self, identity_path: str) -> None: ...
    def set_csrf_token(self, csrf_token: str) -> None: ...
    def set_auth_token(self, auth_token: str) -> None: ...
    def set_api_key(self, api_key: str) -> None: ...

    def set_ssl_ca_cert_from_cert_list_file(self, cert_file_path: str) -> None: ...

    def auth_settings(self) -> Dict[str, Dict[str, Any]]: ...

    def to_debug_report(self) -> str: ...


default_configuration: ClientConfiguration


def Configuration() -> ClientConfiguration: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class SupportRequestInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _attachment: Optional[AttachmentInputV1]
    _attachment_for_jira: Optional[JiraAttachment]
    _description: str
    _email: str
    _frequency: str
    _name: str
    _severity: str
    _steps_to_reproduce: Optional[str]
    _summary: str


    def __init__(
        self,
        attachment: Optional[AttachmentInputV1] = None,
        attachment_for_jira: Optional[JiraAttachment] = None,
        description: Optional[str] = None,
        email: Optional[str] = None,
        frequency: Optional[str] = None,
        name: Optional[str] = None,
        severity: Optional[str] = None,
        steps_to_reproduce: Optional[str] = None,
        summary: Optional[str] = None,
    ) -> None: ...

    @property
    def attachment(self) -> Optional[AttachmentInputV1]: ...

    @attachment.setter
    def attachment(self, attachment: Optional[AttachmentInputV1]) -> None: ...

    @property
    def attachment_for_jira(self) -> Optional[JiraAttachment]: ...

    @attachment_for_jira.setter
    def attachment_for_jira(self, attachment_for_jira: Optional[JiraAttachment]) -> None: ...

    @property
    def description(self) -> str: ...

    @description.setter
    def description(self, description: str) -> None: ...

    @property
    def email(self) -> str: ...

    @email.setter
    def email(self, email: str) -> None: ...

    @property
    def frequency(self) -> str: ...

    @frequency.setter
    def frequency(self, frequency: str) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def severity(self) -> str: ...

    @severity.setter
    def severity(self, severity: str) -> None: ...

    @property
    def steps_to_reproduce(self) -> Optional[str]: ...

    @steps_to_reproduce.setter
    def steps_to_reproduce(self, steps_to_reproduce: Optional[str]) -> None: ...

    @property
    def summary(self) -> str: ...

    @summary.setter
    def summary(self, summary: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class FormulaPackageImportInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _docs: List[FormulaDocInputV1]
    _formula_package: FormulaPackageInputV1
    _functions: List[FunctionInputV1]
    _sync_token: Optional[str]


    def __init__(
        self,
        docs: Optional[List[FormulaDocInputV1]] = None,
        formula_package: Optional[FormulaPackageInputV1] = None,
        functions: Optional[List[FunctionInputV1]] = None,
        sync_token: Optional[str] = None,
    ) -> None: ...

    @property
    def docs(self) -> List[FormulaDocInputV1]: ...

    @docs.setter
    def docs(self, docs: List[FormulaDocInputV1]) -> None: ...

    @property
    def formula_package(self) -> FormulaPackageInputV1: ...

    @formula_package.setter
    def formula_package(self, formula_package: FormulaPackageInputV1) -> None: ...

    @property
    def functions(self) -> List[FunctionInputV1]: ...

    @functions.setter
    def functions(self, functions: List[FunctionInputV1]) -> None: ...

    @property
    def sync_token(self) -> Optional[str]: ...

    @sync_token.setter
    def sync_token(self, sync_token: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class StoredTableColumnInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'column_name': 'str',
        'column_type': 'str',
        'column_uom': 'str',
        'description': 'str',
        'is_hidden': 'bool',
        'is_indexed': 'bool',
        'sort_ascending': 'bool',
        'sort_index': 'int'
    }

    attribute_map = {
        'column_name': 'columnName',
        'column_type': 'columnType',
        'column_uom': 'columnUom',
        'description': 'description',
        'is_hidden': 'isHidden',
        'is_indexed': 'isIndexed',
        'sort_ascending': 'sortAscending',
        'sort_index': 'sortIndex'
    }

    def __init__(self, column_name=None, column_type=None, column_uom=None, description=None, is_hidden=None, is_indexed=None, sort_ascending=None, sort_index=None):
        """
        StoredTableColumnInputV1 - a model defined in Swagger
        """

        self._column_name = None
        self._column_type = None
        self._column_uom = None
        self._description = None
        self._is_hidden = None
        self._is_indexed = None
        self._sort_ascending = None
        self._sort_index = None

        if column_name is not None:
          self.column_name = column_name
        if column_type is not None:
          self.column_type = column_type
        if column_uom is not None:
          self.column_uom = column_uom
        if description is not None:
          self.description = description
        if is_hidden is not None:
          self.is_hidden = is_hidden
        if is_indexed is not None:
          self.is_indexed = is_indexed
        if sort_ascending is not None:
          self.sort_ascending = sort_ascending
        if sort_index is not None:
          self.sort_index = sort_index

    @property
    def column_name(self):
        """
        Gets the column_name of this StoredTableColumnInputV1.
        Name of the column. This will be used as the header for this column. It must be unique for              this table

        :return: The column_name of this StoredTableColumnInputV1.
        :rtype: str
        """
        return self._column_name

    @column_name.setter
    def column_name(self, column_name):
        """
        Sets the column_name of this StoredTableColumnInputV1.
        Name of the column. This will be used as the header for this column. It must be unique for              this table

        :param column_name: The column_name of this StoredTableColumnInputV1.
        :type: str
        """
        if column_name is None:
            raise ValueError("Invalid value for `column_name`, must not be `None`")

        self._column_name = column_name

    @property
    def column_type(self):
        """
        Gets the column_type of this StoredTableColumnInputV1.
        The type for the column

        :return: The column_type of this StoredTableColumnInputV1.
        :rtype: str
        """
        return self._column_type

    @column_type.setter
    def column_type(self, column_type):
        """
        Sets the column_type of this StoredTableColumnInputV1.
        The type for the column

        :param column_type: The column_type of this StoredTableColumnInputV1.
        :type: str
        """
        if column_type is None:
            raise ValueError("Invalid value for `column_type`, must not be `None`")

        self._column_type = column_type

    @property
    def column_uom(self):
        """
        Gets the column_uom of this StoredTableColumnInputV1.
        The unit of measure for this column. This is only applicable to columns whose type                      is NUMERIC. If provided, this will enforce that data in this column must be in this unit. For                      example, if the user specifies Fahrenheit and the value comes in as Meters, the value will not be                      inserted. If not provided, values with different units will be allowed to be stored and an extra                       column will be added to the generated table for the UOM

        :return: The column_uom of this StoredTableColumnInputV1.
        :rtype: str
        """
        return self._column_uom

    @column_uom.setter
    def column_uom(self, column_uom):
        """
        Sets the column_uom of this StoredTableColumnInputV1.
        The unit of measure for this column. This is only applicable to columns whose type                      is NUMERIC. If provided, this will enforce that data in this column must be in this unit. For                      example, if the user specifies Fahrenheit and the value comes in as Meters, the value will not be                      inserted. If not provided, values with different units will be allowed to be stored and an extra                       column will be added to the generated table for the UOM

        :param column_uom: The column_uom of this StoredTableColumnInputV1.
        :type: str
        """

        self._column_uom = column_uom

    @property
    def description(self):
        """
        Gets the description of this StoredTableColumnInputV1.
        The optional description for this column.

        :return: The description of this StoredTableColumnInputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this StoredTableColumnInputV1.
        The optional description for this column.

        :param description: The description of this StoredTableColumnInputV1.
        :type: str
        """

        self._description = description

    @property
    def is_hidden(self):
        """
        Gets the is_hidden of this StoredTableColumnInputV1.

        :return: The is_hidden of this StoredTableColumnInputV1.
        :rtype: bool
        """
        return self._is_hidden

    @is_hidden.setter
    def is_hidden(self, is_hidden):
        """
        Sets the is_hidden of this StoredTableColumnInputV1.

        :param is_hidden: The is_hidden of this StoredTableColumnInputV1.
        :type: bool
        """

        self._is_hidden = is_hidden

    @property
    def is_indexed(self):
        """
        Gets the is_indexed of this StoredTableColumnInputV1.

        :return: The is_indexed of this StoredTableColumnInputV1.
        :rtype: bool
        """
        return self._is_indexed

    @is_indexed.setter
    def is_indexed(self, is_indexed):
        """
        Sets the is_indexed of this StoredTableColumnInputV1.

        :param is_indexed: The is_indexed of this StoredTableColumnInputV1.
        :type: bool
        """

        self._is_indexed = is_indexed

    @property
    def sort_ascending(self):
        """
        Gets the sort_ascending of this StoredTableColumnInputV1.
        Whether to sort ascending if sortIndex is provided, defaults to false

        :return: The sort_ascending of this StoredTableColumnInputV1.
        :rtype: bool
        """
        return self._sort_ascending

    @sort_ascending.setter
    def sort_ascending(self, sort_ascending):
        """
        Sets the sort_ascending of this StoredTableColumnInputV1.
        Whether to sort ascending if sortIndex is provided, defaults to false

        :param sort_ascending: The sort_ascending of this StoredTableColumnInputV1.
        :type: bool
        """

        self._sort_ascending = sort_ascending

    @property
    def sort_index(self):
        """
        Gets the sort_index of this StoredTableColumnInputV1.
        The sort index for this column. If not provided, the column is not sorted.

        :return: The sort_index of this StoredTableColumnInputV1.
        :rtype: int
        """
        return self._sort_index

    @sort_index.setter
    def sort_index(self, sort_index):
        """
        Sets the sort_index of this StoredTableColumnInputV1.
        The sort index for this column. If not provided, the column is not sorted.

        :param sort_index: The sort_index of this StoredTableColumnInputV1.
        :type: int
        """

        self._sort_index = sort_index

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, StoredTableColumnInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ModelTableApplicationsOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _id: Optional[str]
    _mappings: Optional[List[ModelApplicationMappingV1]]
    _model_container_id: Optional[str]
    _model_guid: Optional[str]
    _model_name: Optional[str]
    _updated_at: Optional[str]


    def __init__(
        self,
        id: Optional[str] = None,
        mappings: Optional[List[ModelApplicationMappingV1]] = None,
        model_container_id: Optional[str] = None,
        model_guid: Optional[str] = None,
        model_name: Optional[str] = None,
        updated_at: Optional[str] = None,
    ) -> None: ...

    @property
    def id(self) -> Optional[str]: ...

    @id.setter
    def id(self, id: Optional[str]) -> None: ...

    @property
    def mappings(self) -> Optional[List[ModelApplicationMappingV1]]: ...

    @mappings.setter
    def mappings(self, mappings: Optional[List[ModelApplicationMappingV1]]) -> None: ...

    @property
    def model_container_id(self) -> Optional[str]: ...

    @model_container_id.setter
    def model_container_id(self, model_container_id: Optional[str]) -> None: ...

    @property
    def model_guid(self) -> Optional[str]: ...

    @model_guid.setter
    def model_guid(self, model_guid: Optional[str]) -> None: ...

    @property
    def model_name(self) -> Optional[str]: ...

    @model_name.setter
    def model_name(self, model_name: Optional[str]) -> None: ...

    @property
    def updated_at(self) -> Optional[str]: ...

    @updated_at.setter
    def updated_at(self, updated_at: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class FoldersApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def archive_folder(
        self,
        **kwargs: Any,
    ) -> ArchiveOutputV1: ...

    def archive_folder_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_folder(
        self,
        **kwargs: Any,
    ) -> FolderOutputV1: ...

    def create_folder_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_ancestors(
        self,
        **kwargs: Any,
    ) -> FolderNavigationOutputV1: ...

    def get_ancestors_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_folder(
        self,
        **kwargs: Any,
    ) -> FolderOutputV1: ...

    def get_folder_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_folders(
        self,
        **kwargs: Any,
    ) -> WorkbenchItemOutputListV1: ...

    def get_folders_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_pinned(
        self,
        **kwargs: Any,
    ) -> FolderSearchResultsV1: ...

    def get_pinned_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_recently_used(
        self,
        **kwargs: Any,
    ) -> FolderSearchResultsV1: ...

    def get_recently_used_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_subfolders(
        self,
        **kwargs: Any,
    ) -> FolderNavigationOutputV1: ...

    def get_subfolders_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def move_item_to_folder(
        self,
        **kwargs: Any,
    ) -> FolderOutputV1: ...

    def move_item_to_folder_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def remove_item_from_folder(
        self,
        **kwargs: Any,
    ) -> FolderOutputV1: ...

    def remove_item_from_folder_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def search(
        self,
        **kwargs: Any,
    ) -> FolderSearchResultsV1: ...

    def search_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class LabelHierarchyInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _depth: Optional[int]
    _include_archived: Optional[bool]
    _max_nodes: Optional[int]
    _pairs: Optional[List[CategoryLabelPairInputV1]]


    def __init__(
        self,
        depth: Optional[int] = 10,
        include_archived: Optional[bool] = False,
        max_nodes: Optional[int] = 1000,
        pairs: Optional[List[CategoryLabelPairInputV1]] = None,
    ) -> None: ...

    @property
    def depth(self) -> Optional[int]: ...

    @depth.setter
    def depth(self, depth: Optional[int]) -> None: ...

    @property
    def include_archived(self) -> Optional[bool]: ...

    @include_archived.setter
    def include_archived(self, include_archived: Optional[bool]) -> None: ...

    @property
    def max_nodes(self) -> Optional[int]: ...

    @max_nodes.setter
    def max_nodes(self, max_nodes: Optional[int]) -> None: ...

    @property
    def pairs(self) -> Optional[List[CategoryLabelPairInputV1]]: ...

    @pairs.setter
    def pairs(self, pairs: Optional[List[CategoryLabelPairInputV1]]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class UserGroupOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _capabilities: Optional[List[CapabilityInheritanceOutputV1]]
    _capability_grants: Optional[List[CapabilityInheritanceOutputV1]]
    _created_at: Optional[str]
    _data_id: Optional[str]
    _datasource_class: Optional[str]
    _datasource_id: Optional[str]
    _datasource_name: Optional[str]
    _description: Optional[str]
    _effective_permissions: Optional[PermissionsV1]
    _id: str
    _is_archived: Optional[bool]
    _is_enabled: Optional[bool]
    _is_organization_group: Optional[bool]
    _is_redacted: Optional[bool]
    _is_remote_group_editable: Optional[bool]
    _is_used_in_access_control_entries: Optional[bool]
    _members: Optional[List[IdentityPreviewV1]]
    _name: str
    _status_message: Optional[str]
    _sync_token: Optional[str]
    _translation_key: Optional[str]
    _type: str


    def __init__(
        self,
        capabilities: Optional[List[CapabilityInheritanceOutputV1]] = None,
        capability_grants: Optional[List[CapabilityInheritanceOutputV1]] = None,
        created_at: Optional[str] = None,
        data_id: Optional[str] = None,
        datasource_class: Optional[str] = None,
        datasource_id: Optional[str] = None,
        datasource_name: Optional[str] = None,
        description: Optional[str] = None,
        effective_permissions: Optional[PermissionsV1] = None,
        id: Optional[str] = None,
        is_archived: Optional[bool] = False,
        is_enabled: Optional[bool] = False,
        is_organization_group: Optional[bool] = False,
        is_redacted: Optional[bool] = False,
        is_remote_group_editable: Optional[bool] = False,
        is_used_in_access_control_entries: Optional[bool] = False,
        members: Optional[List[IdentityPreviewV1]] = None,
        name: Optional[str] = None,
        status_message: Optional[str] = None,
        sync_token: Optional[str] = None,
        translation_key: Optional[str] = None,
        type: Optional[str] = None,
    ) -> None: ...

    @property
    def capabilities(self) -> Optional[List[CapabilityInheritanceOutputV1]]: ...

    @capabilities.setter
    def capabilities(self, capabilities: Optional[List[CapabilityInheritanceOutputV1]]) -> None: ...

    @property
    def capability_grants(self) -> Optional[List[CapabilityInheritanceOutputV1]]: ...

    @capability_grants.setter
    def capability_grants(self, capability_grants: Optional[List[CapabilityInheritanceOutputV1]]) -> None: ...

    @property
    def created_at(self) -> Optional[str]: ...

    @created_at.setter
    def created_at(self, created_at: Optional[str]) -> None: ...

    @property
    def data_id(self) -> Optional[str]: ...

    @data_id.setter
    def data_id(self, data_id: Optional[str]) -> None: ...

    @property
    def datasource_class(self) -> Optional[str]: ...

    @datasource_class.setter
    def datasource_class(self, datasource_class: Optional[str]) -> None: ...

    @property
    def datasource_id(self) -> Optional[str]: ...

    @datasource_id.setter
    def datasource_id(self, datasource_id: Optional[str]) -> None: ...

    @property
    def datasource_name(self) -> Optional[str]: ...

    @datasource_name.setter
    def datasource_name(self, datasource_name: Optional[str]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def effective_permissions(self) -> Optional[PermissionsV1]: ...

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions: Optional[PermissionsV1]) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def is_archived(self) -> Optional[bool]: ...

    @is_archived.setter
    def is_archived(self, is_archived: Optional[bool]) -> None: ...

    @property
    def is_enabled(self) -> Optional[bool]: ...

    @is_enabled.setter
    def is_enabled(self, is_enabled: Optional[bool]) -> None: ...

    @property
    def is_organization_group(self) -> Optional[bool]: ...

    @is_organization_group.setter
    def is_organization_group(self, is_organization_group: Optional[bool]) -> None: ...

    @property
    def is_redacted(self) -> Optional[bool]: ...

    @is_redacted.setter
    def is_redacted(self, is_redacted: Optional[bool]) -> None: ...

    @property
    def is_remote_group_editable(self) -> Optional[bool]: ...

    @is_remote_group_editable.setter
    def is_remote_group_editable(self, is_remote_group_editable: Optional[bool]) -> None: ...

    @property
    def is_used_in_access_control_entries(self) -> Optional[bool]: ...

    @is_used_in_access_control_entries.setter
    def is_used_in_access_control_entries(self, is_used_in_access_control_entries: Optional[bool]) -> None: ...

    @property
    def members(self) -> Optional[List[IdentityPreviewV1]]: ...

    @members.setter
    def members(self, members: Optional[List[IdentityPreviewV1]]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def status_message(self) -> Optional[str]: ...

    @status_message.setter
    def status_message(self, status_message: Optional[str]) -> None: ...

    @property
    def sync_token(self) -> Optional[str]: ...

    @sync_token.setter
    def sync_token(self, sync_token: Optional[str]) -> None: ...

    @property
    def translation_key(self) -> Optional[str]: ...

    @translation_key.setter
    def translation_key(self, translation_key: Optional[str]) -> None: ...

    @property
    def type(self) -> str: ...

    @type.setter
    def type(self, type: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class TableDataQueryInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _columns_to_include: Optional[List[str]]
    _condition_monitor_id: Optional[str]
    _cursor: Optional[Cursor]
    _distinct_on_columns: Optional[List[str]]
    _filter: Optional[Filter]
    _group_by: Optional[GroupBy]
    _include_overrides: Optional[bool]
    _limit: int
    _properties_to_include: Optional[List[PropertiesForItemUUIDColumn]]
    _sorts: Optional[List[Sort]]
    _table_formulas: Optional[List[TableFormula]]
    _tables_to_join: Optional[List[TableJoinInput]]
    _use_distinct: Optional[bool]
    _virtual_columns: Optional[VirtualColumns]


    def __init__(
        self,
        columns_to_include: Optional[List[str]] = None,
        condition_monitor_id: Optional[str] = None,
        cursor: Optional[Cursor] = None,
        distinct_on_columns: Optional[List[str]] = None,
        filter: Optional[Filter] = None,
        group_by: Optional[GroupBy] = None,
        include_overrides: Optional[bool] = None,
        limit: Optional[int] = None,
        properties_to_include: Optional[List[PropertiesForItemUUIDColumn]] = None,
        sorts: Optional[List[Sort]] = None,
        table_formulas: Optional[List[TableFormula]] = None,
        tables_to_join: Optional[List[TableJoinInput]] = None,
        use_distinct: Optional[bool] = None,
        virtual_columns: Optional[VirtualColumns] = None,
    ) -> None: ...

    @property
    def columns_to_include(self) -> Optional[List[str]]: ...

    @columns_to_include.setter
    def columns_to_include(self, columns_to_include: Optional[List[str]]) -> None: ...

    @property
    def condition_monitor_id(self) -> Optional[str]: ...

    @condition_monitor_id.setter
    def condition_monitor_id(self, condition_monitor_id: Optional[str]) -> None: ...

    @property
    def cursor(self) -> Optional[Cursor]: ...

    @cursor.setter
    def cursor(self, cursor: Optional[Cursor]) -> None: ...

    @property
    def distinct_on_columns(self) -> Optional[List[str]]: ...

    @distinct_on_columns.setter
    def distinct_on_columns(self, distinct_on_columns: Optional[List[str]]) -> None: ...

    @property
    def filter(self) -> Optional[Filter]: ...

    @filter.setter
    def filter(self, filter: Optional[Filter]) -> None: ...

    @property
    def group_by(self) -> Optional[GroupBy]: ...

    @group_by.setter
    def group_by(self, group_by: Optional[GroupBy]) -> None: ...

    @property
    def include_overrides(self) -> Optional[bool]: ...

    @include_overrides.setter
    def include_overrides(self, include_overrides: Optional[bool]) -> None: ...

    @property
    def limit(self) -> int: ...

    @limit.setter
    def limit(self, limit: int) -> None: ...

    @property
    def properties_to_include(self) -> Optional[List[PropertiesForItemUUIDColumn]]: ...

    @properties_to_include.setter
    def properties_to_include(self, properties_to_include: Optional[List[PropertiesForItemUUIDColumn]]) -> None: ...

    @property
    def sorts(self) -> Optional[List[Sort]]: ...

    @sorts.setter
    def sorts(self, sorts: Optional[List[Sort]]) -> None: ...

    @property
    def table_formulas(self) -> Optional[List[TableFormula]]: ...

    @table_formulas.setter
    def table_formulas(self, table_formulas: Optional[List[TableFormula]]) -> None: ...

    @property
    def tables_to_join(self) -> Optional[List[TableJoinInput]]: ...

    @tables_to_join.setter
    def tables_to_join(self, tables_to_join: Optional[List[TableJoinInput]]) -> None: ...

    @property
    def use_distinct(self) -> Optional[bool]: ...

    @use_distinct.setter
    def use_distinct(self, use_distinct: Optional[bool]) -> None: ...

    @property
    def virtual_columns(self) -> Optional[VirtualColumns]: ...

    @virtual_columns.setter
    def virtual_columns(self, virtual_columns: Optional[VirtualColumns]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class UserInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _access_key_validity_duration: Optional[int]
    _data_id: Optional[str]
    _datasource_class: Optional[str]
    _datasource_id: Optional[str]
    _description: Optional[str]
    _email: str
    _first_name: str
    _is_admin: Optional[bool]
    _is_enabled: Optional[bool]
    _last_name: str
    _manager: Optional[str]
    _max_requests: Optional[int]
    _name: Optional[str]
    _password: Optional[str]
    _require_password_reset_on_next_login: Optional[bool]
    _role: Optional[str]
    _session_duration: Optional[int]
    _site: Optional[str]
    _template_workstep_id: Optional[str]
    _username: str
    _workbench: Optional[str]


    def __init__(
        self,
        access_key_validity_duration: Optional[int] = None,
        data_id: Optional[str] = None,
        datasource_class: Optional[str] = None,
        datasource_id: Optional[str] = None,
        description: Optional[str] = None,
        email: Optional[str] = None,
        first_name: Optional[str] = None,
        is_admin: Optional[bool] = None,
        is_enabled: Optional[bool] = None,
        last_name: Optional[str] = None,
        manager: Optional[str] = None,
        max_requests: Optional[int] = None,
        name: Optional[str] = None,
        password: Optional[str] = None,
        require_password_reset_on_next_login: Optional[bool] = None,
        role: Optional[str] = None,
        session_duration: Optional[int] = None,
        site: Optional[str] = None,
        template_workstep_id: Optional[str] = None,
        username: Optional[str] = None,
        workbench: Optional[str] = None,
    ) -> None: ...

    @property
    def access_key_validity_duration(self) -> Optional[int]: ...

    @access_key_validity_duration.setter
    def access_key_validity_duration(self, access_key_validity_duration: Optional[int]) -> None: ...

    @property
    def data_id(self) -> Optional[str]: ...

    @data_id.setter
    def data_id(self, data_id: Optional[str]) -> None: ...

    @property
    def datasource_class(self) -> Optional[str]: ...

    @datasource_class.setter
    def datasource_class(self, datasource_class: Optional[str]) -> None: ...

    @property
    def datasource_id(self) -> Optional[str]: ...

    @datasource_id.setter
    def datasource_id(self, datasource_id: Optional[str]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def email(self) -> str: ...

    @email.setter
    def email(self, email: str) -> None: ...

    @property
    def first_name(self) -> str: ...

    @first_name.setter
    def first_name(self, first_name: str) -> None: ...

    @property
    def is_admin(self) -> Optional[bool]: ...

    @is_admin.setter
    def is_admin(self, is_admin: Optional[bool]) -> None: ...

    @property
    def is_enabled(self) -> Optional[bool]: ...

    @is_enabled.setter
    def is_enabled(self, is_enabled: Optional[bool]) -> None: ...

    @property
    def last_name(self) -> str: ...

    @last_name.setter
    def last_name(self, last_name: str) -> None: ...

    @property
    def manager(self) -> Optional[str]: ...

    @manager.setter
    def manager(self, manager: Optional[str]) -> None: ...

    @property
    def max_requests(self) -> Optional[int]: ...

    @max_requests.setter
    def max_requests(self, max_requests: Optional[int]) -> None: ...

    @property
    def name(self) -> Optional[str]: ...

    @name.setter
    def name(self, name: Optional[str]) -> None: ...

    @property
    def password(self) -> Optional[str]: ...

    @password.setter
    def password(self, password: Optional[str]) -> None: ...

    @property
    def require_password_reset_on_next_login(self) -> Optional[bool]: ...

    @require_password_reset_on_next_login.setter
    def require_password_reset_on_next_login(self, require_password_reset_on_next_login: Optional[bool]) -> None: ...

    @property
    def role(self) -> Optional[str]: ...

    @role.setter
    def role(self, role: Optional[str]) -> None: ...

    @property
    def session_duration(self) -> Optional[int]: ...

    @session_duration.setter
    def session_duration(self, session_duration: Optional[int]) -> None: ...

    @property
    def site(self) -> Optional[str]: ...

    @site.setter
    def site(self, site: Optional[str]) -> None: ...

    @property
    def template_workstep_id(self) -> Optional[str]: ...

    @template_workstep_id.setter
    def template_workstep_id(self, template_workstep_id: Optional[str]) -> None: ...

    @property
    def username(self) -> str: ...

    @username.setter
    def username(self, username: str) -> None: ...

    @property
    def workbench(self) -> Optional[str]: ...

    @workbench.setter
    def workbench(self, workbench: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class NotificationConfigurationOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _bcc_email_recipients: List[EmailNotificationRecipientOutputV1]
    _capsule_grouping: Optional[str]
    _capsule_properties: List[str]
    _cc_email_recipients: List[EmailNotificationRecipientOutputV1]
    _contextual_text: Optional[str]
    _reply_to_email_recipients: List[EmailNotificationRecipientOutputV1]
    _report_format: Optional[str]
    _subject: Optional[str]
    _timezone: Optional[str]
    _to_email_recipients: List[EmailNotificationRecipientOutputV1]


    def __init__(
        self,
        bcc_email_recipients: Optional[List[EmailNotificationRecipientOutputV1]] = None,
        capsule_grouping: Optional[str] = None,
        capsule_properties: Optional[List[str]] = None,
        cc_email_recipients: Optional[List[EmailNotificationRecipientOutputV1]] = None,
        contextual_text: Optional[str] = None,
        reply_to_email_recipients: Optional[List[EmailNotificationRecipientOutputV1]] = None,
        report_format: Optional[str] = None,
        subject: Optional[str] = None,
        timezone: Optional[str] = None,
        to_email_recipients: Optional[List[EmailNotificationRecipientOutputV1]] = None,
    ) -> None: ...

    @property
    def bcc_email_recipients(self) -> List[EmailNotificationRecipientOutputV1]: ...

    @bcc_email_recipients.setter
    def bcc_email_recipients(self, bcc_email_recipients: List[EmailNotificationRecipientOutputV1]) -> None: ...

    @property
    def capsule_grouping(self) -> Optional[str]: ...

    @capsule_grouping.setter
    def capsule_grouping(self, capsule_grouping: Optional[str]) -> None: ...

    @property
    def capsule_properties(self) -> List[str]: ...

    @capsule_properties.setter
    def capsule_properties(self, capsule_properties: List[str]) -> None: ...

    @property
    def cc_email_recipients(self) -> List[EmailNotificationRecipientOutputV1]: ...

    @cc_email_recipients.setter
    def cc_email_recipients(self, cc_email_recipients: List[EmailNotificationRecipientOutputV1]) -> None: ...

    @property
    def contextual_text(self) -> Optional[str]: ...

    @contextual_text.setter
    def contextual_text(self, contextual_text: Optional[str]) -> None: ...

    @property
    def reply_to_email_recipients(self) -> List[EmailNotificationRecipientOutputV1]: ...

    @reply_to_email_recipients.setter
    def reply_to_email_recipients(self, reply_to_email_recipients: List[EmailNotificationRecipientOutputV1]) -> None: ...

    @property
    def report_format(self) -> Optional[str]: ...

    @report_format.setter
    def report_format(self, report_format: Optional[str]) -> None: ...

    @property
    def subject(self) -> Optional[str]: ...

    @subject.setter
    def subject(self, subject: Optional[str]) -> None: ...

    @property
    def timezone(self) -> Optional[str]: ...

    @timezone.setter
    def timezone(self, timezone: Optional[str]) -> None: ...

    @property
    def to_email_recipients(self) -> List[EmailNotificationRecipientOutputV1]: ...

    @to_email_recipients.setter
    def to_email_recipients(self, to_email_recipients: List[EmailNotificationRecipientOutputV1]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ServerStatusOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _async_migrations_complete: Optional[bool]
    _async_migrations_semantic_version: Optional[str]
    _at_user_limit: Optional[bool]
    _configuration_options: Optional[List[ConfigurationOptionOutputSimpleV1]]
    _default_max_capsule_duration: Optional[ScalarValueOutputV1]
    _default_max_interpolation: Optional[ScalarValueOutputV1]
    _is_data_lab_available: Optional[bool]
    _priorities: Optional[List[PriorityV1]]
    _seeq_gpt_enabled: Optional[bool]
    _server_specs: Optional[List[ServerSpecOutputV1]]
    _time_zone: Optional[str]
    _version: Optional[str]


    def __init__(
        self,
        async_migrations_complete: Optional[bool] = None,
        async_migrations_semantic_version: Optional[str] = None,
        at_user_limit: Optional[bool] = False,
        configuration_options: Optional[List[ConfigurationOptionOutputSimpleV1]] = None,
        default_max_capsule_duration: Optional[ScalarValueOutputV1] = None,
        default_max_interpolation: Optional[ScalarValueOutputV1] = None,
        is_data_lab_available: Optional[bool] = False,
        priorities: Optional[List[PriorityV1]] = None,
        seeq_gpt_enabled: Optional[bool] = False,
        server_specs: Optional[List[ServerSpecOutputV1]] = None,
        time_zone: Optional[str] = None,
        version: Optional[str] = None,
    ) -> None: ...

    @property
    def async_migrations_complete(self) -> Optional[bool]: ...

    @async_migrations_complete.setter
    def async_migrations_complete(self, async_migrations_complete: Optional[bool]) -> None: ...

    @property
    def async_migrations_semantic_version(self) -> Optional[str]: ...

    @async_migrations_semantic_version.setter
    def async_migrations_semantic_version(self, async_migrations_semantic_version: Optional[str]) -> None: ...

    @property
    def at_user_limit(self) -> Optional[bool]: ...

    @at_user_limit.setter
    def at_user_limit(self, at_user_limit: Optional[bool]) -> None: ...

    @property
    def configuration_options(self) -> Optional[List[ConfigurationOptionOutputSimpleV1]]: ...

    @configuration_options.setter
    def configuration_options(self, configuration_options: Optional[List[ConfigurationOptionOutputSimpleV1]]) -> None: ...

    @property
    def default_max_capsule_duration(self) -> Optional[ScalarValueOutputV1]: ...

    @default_max_capsule_duration.setter
    def default_max_capsule_duration(self, default_max_capsule_duration: Optional[ScalarValueOutputV1]) -> None: ...

    @property
    def default_max_interpolation(self) -> Optional[ScalarValueOutputV1]: ...

    @default_max_interpolation.setter
    def default_max_interpolation(self, default_max_interpolation: Optional[ScalarValueOutputV1]) -> None: ...

    @property
    def is_data_lab_available(self) -> Optional[bool]: ...

    @is_data_lab_available.setter
    def is_data_lab_available(self, is_data_lab_available: Optional[bool]) -> None: ...

    @property
    def priorities(self) -> Optional[List[PriorityV1]]: ...

    @priorities.setter
    def priorities(self, priorities: Optional[List[PriorityV1]]) -> None: ...

    @property
    def seeq_gpt_enabled(self) -> Optional[bool]: ...

    @seeq_gpt_enabled.setter
    def seeq_gpt_enabled(self, seeq_gpt_enabled: Optional[bool]) -> None: ...

    @property
    def server_specs(self) -> Optional[List[ServerSpecOutputV1]]: ...

    @server_specs.setter
    def server_specs(self, server_specs: Optional[List[ServerSpecOutputV1]]) -> None: ...

    @property
    def time_zone(self) -> Optional[str]: ...

    @time_zone.setter
    def time_zone(self, time_zone: Optional[str]) -> None: ...

    @property
    def version(self) -> Optional[str]: ...

    @version.setter
    def version(self, version: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class LogMessage(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _exception: Optional[str]
    _failure_reasons: Optional[List[str]]
    _formatted_level: Optional[str]
    _level: str
    _logger_name: Optional[str]
    _message: str
    _source: str
    _time: str
    _valid: Optional[bool]


    def __init__(
        self,
        exception: Optional[str] = None,
        failure_reasons: Optional[List[str]] = None,
        formatted_level: Optional[str] = None,
        level: Optional[str] = None,
        logger_name: Optional[str] = None,
        message: Optional[str] = None,
        source: Optional[str] = None,
        time: Optional[str] = None,
        valid: Optional[bool] = None,
    ) -> None: ...

    @property
    def exception(self) -> Optional[str]: ...

    @exception.setter
    def exception(self, exception: Optional[str]) -> None: ...

    @property
    def failure_reasons(self) -> Optional[List[str]]: ...

    @failure_reasons.setter
    def failure_reasons(self, failure_reasons: Optional[List[str]]) -> None: ...

    @property
    def formatted_level(self) -> Optional[str]: ...

    @formatted_level.setter
    def formatted_level(self, formatted_level: Optional[str]) -> None: ...

    @property
    def level(self) -> str: ...

    @level.setter
    def level(self, level: str) -> None: ...

    @property
    def logger_name(self) -> Optional[str]: ...

    @logger_name.setter
    def logger_name(self, logger_name: Optional[str]) -> None: ...

    @property
    def message(self) -> str: ...

    @message.setter
    def message(self, message: str) -> None: ...

    @property
    def source(self) -> str: ...

    @source.setter
    def source(self, source: str) -> None: ...

    @property
    def time(self) -> str: ...

    @time.setter
    def time(self, time: str) -> None: ...

    @property
    def valid(self) -> Optional[bool]: ...

    @valid.setter
    def valid(self, valid: Optional[bool]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class SignalMonitorInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _description: Optional[str]
    _enabled: Optional[bool]
    _first_run_look_back: Optional[int]
    _frequency: str
    _name: str
    _query_range_look_ahead: Optional[int]
    _sample_event_types: Optional[List[str]]
    _scoped_to: Optional[str]
    _signal_ids: List[str]
    _timezone: Optional[str]


    def __init__(
        self,
        description: Optional[str] = None,
        enabled: Optional[bool] = True,
        first_run_look_back: Optional[int] = None,
        frequency: Optional[str] = None,
        name: Optional[str] = None,
        query_range_look_ahead: Optional[int] = None,
        sample_event_types: Optional[List[str]] = None,
        scoped_to: Optional[str] = None,
        signal_ids: Optional[List[str]] = None,
        timezone: Optional[str] = None,
    ) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def enabled(self) -> Optional[bool]: ...

    @enabled.setter
    def enabled(self, enabled: Optional[bool]) -> None: ...

    @property
    def first_run_look_back(self) -> Optional[int]: ...

    @first_run_look_back.setter
    def first_run_look_back(self, first_run_look_back: Optional[int]) -> None: ...

    @property
    def frequency(self) -> str: ...

    @frequency.setter
    def frequency(self, frequency: str) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def query_range_look_ahead(self) -> Optional[int]: ...

    @query_range_look_ahead.setter
    def query_range_look_ahead(self, query_range_look_ahead: Optional[int]) -> None: ...

    @property
    def sample_event_types(self) -> Optional[List[str]]: ...

    @sample_event_types.setter
    def sample_event_types(self, sample_event_types: Optional[List[str]]) -> None: ...

    @property
    def scoped_to(self) -> Optional[str]: ...

    @scoped_to.setter
    def scoped_to(self, scoped_to: Optional[str]) -> None: ...

    @property
    def signal_ids(self) -> List[str]: ...

    @signal_ids.setter
    def signal_ids(self, signal_ids: List[str]) -> None: ...

    @property
    def timezone(self) -> Optional[str]: ...

    @timezone.setter
    def timezone(self, timezone: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class AssetTreeBatchInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _child_host_id: str
    _disable_asset_tree_index_update_during_sync: Optional[bool]
    _parent_host_id: str
    _relationships: Optional[List[AssetTreeSingleInputV1]]


    def __init__(
        self,
        child_host_id: Optional[str] = None,
        disable_asset_tree_index_update_during_sync: Optional[bool] = False,
        parent_host_id: Optional[str] = None,
        relationships: Optional[List[AssetTreeSingleInputV1]] = None,
    ) -> None: ...

    @property
    def child_host_id(self) -> str: ...

    @child_host_id.setter
    def child_host_id(self, child_host_id: str) -> None: ...

    @property
    def disable_asset_tree_index_update_during_sync(self) -> Optional[bool]: ...

    @disable_asset_tree_index_update_during_sync.setter
    def disable_asset_tree_index_update_during_sync(self, disable_asset_tree_index_update_during_sync: Optional[bool]) -> None: ...

    @property
    def parent_host_id(self) -> str: ...

    @parent_host_id.setter
    def parent_host_id(self, parent_host_id: str) -> None: ...

    @property
    def relationships(self) -> Optional[List[AssetTreeSingleInputV1]]: ...

    @relationships.setter
    def relationships(self, relationships: Optional[List[AssetTreeSingleInputV1]]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
